@@ -1,6 +1,6 @@
 import json
 import os
-from typing import Dict
+from typing import Optional, Dict
 
 current_dir = os.path.dirname(__file__)
 
@@ -18,7 +18,7 @@ class Locations:
             return json.load(countries_file)
 
     @staticmethod
-    def statesList(country_code: str) -> Dict | None:
+    def statesList(country_code: str) -> Optional[Dict]:
         """Get states list by country ISO code
 
         Args:
